@@ -1,4 +1,4 @@
-# $Id: Item.pm 1202 2006-06-04 18:59:10Z claco $
+# $Id: Item.pm 1314 2006-07-10 00:29:55Z claco $
 package Handel::Cart::Item;
 use strict;
 use warnings;
@@ -6,23 +6,26 @@ use warnings;
 BEGIN {
     use Handel;
     use Handel::Constraints qw(:all);
-    use Handel::Currency;
     use Handel::L10N qw(translate);
 
-    use base qw/Handel::Storage/;
-    __PACKAGE__->schema_class('Handel::Cart::Schema');
-    __PACKAGE__->schema_source('Items');
-    __PACKAGE__->setup_column_accessors;
-    __PACKAGE__->add_constraint('quantity', quantity => \&constraint_quantity);
-    __PACKAGE__->add_constraint('price',    price    => \&constraint_price);
-    __PACKAGE__->add_constraint('id',       id       => \&constraint_uuid);
-    __PACKAGE__->add_constraint('cart',     cart     => \&constraint_uuid);
-
-    __PACKAGE__->default_values({
-        id       => \&Handel::Storage::uuid,
-        price    => 0,
-        quantity => 1
+    use base qw/Handel::Base/;
+    __PACKAGE__->storage({
+        schema_class     => 'Handel::Cart::Schema',
+        schema_source    => 'Items',
+        currency_columns => [qw/price/],
+        constraints      => {
+            quantity     => {'Check Quantity' => \&constraint_quantity},
+            price        => {'Check Price'    => \&constraint_price},
+            id           => {'Check Id'       => \&constraint_uuid},
+            cart         => {'Check Cart'     => \&constraint_uuid}
+        },
+        default_values   => {
+            id           => __PACKAGE__->storage_class->can('new_uuid'),
+            price        => 0,
+            quantity     => 1
+        }
     });
+    __PACKAGE__->create_accessors;
 };
 
 sub new {
@@ -33,7 +36,8 @@ sub new {
             ref($data) eq 'HASH';
 
     my $self = bless {
-        storage => $class->schema_instance->resultset($class->schema_source)->create($data)
+        result => $class->storage->schema_instance->resultset($class->storage->schema_source)->create($data),
+        autoupdate => $class->storage->autoupdate
     }, $class;
 
     return $self;
@@ -41,7 +45,7 @@ sub new {
 
 sub total {
     my $self = shift;
-    return Handel::Currency->new($self->quantity * $self->price);
+    return $self->storage->currency_class->new($self->quantity * $self->price);
 };
 
 1;
