@@ -1,4 +1,4 @@
-# $Id: Order.pm 1202 2006-06-04 18:59:10Z claco $
+# $Id: Order.pm 1314 2006-07-10 00:29:55Z claco $
 package Handel::Order;
 use strict;
 use warnings;
@@ -12,38 +12,14 @@ BEGIN {
     use Handel::L10N qw/translate/;
     use Scalar::Util qw/blessed/;
 
-    use base qw/Handel::Storage/;
-    __PACKAGE__->schema_class('Handel::Order::Schema');
-    __PACKAGE__->schema_source('Orders');
-    __PACKAGE__->item_class('Handel::Order::Item');
-    __PACKAGE__->cart_class('Handel::Cart');
-    __PACKAGE__->setup_column_accessors;
-
-    __PACKAGE__->add_constraint('id',       id       => \&constraint_uuid);
-    __PACKAGE__->add_constraint('shopper',  shopper  => \&constraint_uuid);
-    __PACKAGE__->add_constraint('type',     type     => \&constraint_order_type);
-    __PACKAGE__->add_constraint('shipping', shipping => \&constraint_price);
-    __PACKAGE__->add_constraint('handling', handling => \&constraint_price);
-    __PACKAGE__->add_constraint('subtotal', subtotal => \&constraint_price);
-    __PACKAGE__->add_constraint('tax',      tax      => \&constraint_price);
-    __PACKAGE__->add_constraint('total',    total    => \&constraint_price);
-
-    __PACKAGE__->mk_classaccessors(qw/ccn cctype ccm ccy ccvn ccname ccissuenumber ccstartdate ccenddate/);
-
-    __PACKAGE__->default_values({
-        id       => \&Handel::Storage::uuid,
-        type     => ORDER_TYPE_TEMP,
-        shipping => 0,
-        handling => 0,
-        subtotal => 0,
-        tax      => 0,
-        total    => 0
-    });
+    use base qw/Handel::Base/;
+    __PACKAGE__->storage_class('Handel::Storage::Order');
+    __PACKAGE__->mk_group_accessors('inherited', qw/ccn cctype ccm ccy ccvn ccname ccissuenumber ccstartdate ccenddate/);
+    __PACKAGE__->create_accessors;
 };
 
 sub new {
     my ($class, $data, $process) = @_;
-    $class = ref $class || $class;
 
     throw Handel::Exception::Argument(
         -details => translate('Param 1 is not a HASH reference') . '.') unless
@@ -59,13 +35,13 @@ sub new {
                   (ref($cart) eq 'HASH' or (blessed($cart) && $cart->isa('Handel::Cart')) or $is_uuid);
 
         if (ref $cart eq 'HASH') {
-            $cart = $class->cart_class->load($cart)->first;
+            $cart = $class->storage->cart_class->load($cart)->first;
 
             throw Handel::Exception::Order( -details =>
                 translate(
                     'Could not find a cart matching the supplied search criteria') . '.') unless $cart;
         } elsif ($is_uuid) {
-            $cart = $class->cart_class->load({id => $cart})->first;
+            $cart = $class->storage->cart_class->load({id => $cart})->first;
 
             throw Handel::Exception::Order( -details =>
                 translate(
@@ -83,8 +59,9 @@ sub new {
     };
 
     my $order = bless {
-        storage => $class->schema_instance->resultset($class->schema_source)->create($data)
-    }, $class;
+        result => $class->storage->schema_instance->resultset($class->storage->schema_source)->create($data),
+        autoupdate => $class->storage->autoupdate
+    }, ref $class || $class;
 
 
     if (defined $cart) {
@@ -122,23 +99,21 @@ sub copy_cart {
 
 sub copy_cart_items {
     my ($self, $order, $cart) = @_;
-    my %columns = map {$_ => $_} $order->schema_class->class($order->item_class->schema_source)->columns;
+    my %columns = map {$_ => $_} $order->storage->schema_class->source($order->storage->item_class->storage->schema_source)->columns;
 
     foreach my $item ($cart->items) {
         my %copy;
 
-        foreach ($cart->item_class->schema_class->class($cart->item_class->schema_source)->columns) {
+        foreach ($cart->storage->item_class->storage->schema_class->source($cart->storage->item_class->storage->schema_source)->columns) {
             next if $_ =~ /^(id|cart)$/i;
             next unless (exists $columns{$_});
 
-            $copy{$_} = $item->storage->$_;
+            $copy{$_} = $item->result->$_;
         };
 
-        $copy{'id'} = $self->uuid unless Handel::Constraints::constraint_uuid($copy{'id'});
-        $copy{'orderid'} = $order->id;
         $copy{'total'} = $copy{'quantity'}*$copy{'price'};
 
-        $order->storage->create_related($self->item_relationship, \%copy);
+        $order->result->create_related($order->storage->item_relationship, \%copy);
     };
 };
 
@@ -152,31 +127,31 @@ sub add {
 
     if (ref($data) eq 'HASH') {
         return bless {
-            storage => $self->storage->create_related($self->item_relationship, $data)
-        }, $self->item_class;
+            result => $self->result->create_related($self->storage->item_relationship, $data),
+            autoupdate => $self->storage->item_class->storage->autoupdate
+        }, $self->storage->item_class;
     } else {
         my %copy;
 
-        foreach ($data->storage->columns) {
+        foreach ($data->result->columns) {
             next if $_ =~ /^(id|orderid|cart)$/i;
-            $copy{$_} = $data->storage->$_;
+            $copy{$_} = $data->result->$_;
         };
         if (blessed($data) && $data->isa('Handel::Cart::Item')) {
             $copy{'total'} = $data->total;
         };
 
-        $copy{'id'} = $self->uuid;
-
         return bless {
-            storage => $self->storage->create_related($self->item_relationship, \%copy)
-        }, $self->item_class;
+            result => $self->result->create_related($self->storage->item_relationship, \%copy),
+            autoupdate => $self->storage->item_class->storage->autoupdate
+        }, $self->storage->item_class;
     };
 };
 
 sub clear {
     my $self = shift;
 
-    $self->storage->delete_related($self->item_relationship);
+    $self->result->delete_related($self->storage->item_relationship);
 
     return undef;
 };
@@ -184,7 +159,7 @@ sub clear {
 sub count {
     my $self  = shift;
 
-    return $self->storage->count_related($self->item_relationship) || 0;
+    return $self->result->count_related($self->storage->item_relationship) || 0;
 };
 
 sub delete {
@@ -194,24 +169,24 @@ sub delete {
         translate('Param 1 is not a HASH reference') . '.') unless
             ref($filter) eq 'HASH';
 
-    $filter = $self->_migrate_wildcards($filter);
+    $filter = $self->storage->_migrate_wildcards($filter);
 
-    return $self->storage->delete_related($self->item_relationship, $filter);
+    return $self->result->delete_related($self->storage->item_relationship, $filter);
 };
 
 sub destroy {
     my ($self, $filter) = @_;
 
     if (ref $self) {
-        $self->storage->delete;
+        $self->result->delete;
     } else {
         throw Handel::Exception::Argument( -details =>
             translate('Param 1 is not a HASH reference') . '.') unless
                 ref($filter) eq 'HASH';
 
-        $filter = $self->_migrate_wildcards($filter);
+        $filter = $self->storage->_migrate_wildcards($filter);
 
-        $self->schema_instance->resultset($self->schema_source)->search($filter)->delete_all;
+        $self->storage->schema_instance->resultset($self->storage->schema_source)->search($filter)->delete_all;
     };
 
     return;
@@ -224,15 +199,15 @@ sub items {
         translate('Param 1 is not a HASH reference') . '.') unless(
             ref($filter) eq 'HASH' or !$filter);
 
-    $filter = $self->_migrate_wildcards($filter);
+    $filter = $self->storage->_migrate_wildcards($filter);
 
     if (wantarray) {
-        my @items = $self->storage->search_related($self->item_relationship, $filter)->all;
+        my @items = $self->result->search_related($self->storage->item_relationship, $filter)->all;
 
-        return map {bless {storage => $_}, $self->item_class} @items;
+        return map {bless {result => $_, autoupdate => $self->storage->item_class->storage->autoupdate}, $self->storage->item_class} @items;
     } else {
-        my $iterator = $self->storage->search_related_rs($self->item_relationship, $filter);
-        $iterator->result_class($self->item_class);
+        my $iterator = $self->result->search_related_rs($self->storage->item_relationship, $filter);
+        $iterator->result_class($self->storage->item_class);
 
         return $iterator;
     };
@@ -240,21 +215,20 @@ sub items {
 
 sub load {
     my ($class, $filter) = @_;
-    $class = ref $class || $class;
 
     throw Handel::Exception::Argument( -details =>
         translate('Param 1 is not a HASH reference') . '.') unless(
             ref($filter) eq 'HASH' or !$filter);
 
-    $filter = $class->_migrate_wildcards($filter);
+    $filter = $class->storage->_migrate_wildcards($filter);
 
     if (wantarray) {
-        my @carts = $class->schema_instance->resultset($class->schema_source)->search($filter)->all;
+        my @carts = $class->storage->schema_instance->resultset($class->storage->schema_source)->search($filter)->all;
 
-        return map {bless {storage => $_}, $class} @carts;
+        return map {bless {result => $_, autoupdate => $class->storage->autoupdate}, ref $class || $class} @carts;
     } else {
-        my $iterator = $class->schema_instance->resultset($class->schema_source)->search_rs($filter);
-        $iterator->result_class($class);
+        my $iterator = $class->storage->schema_instance->resultset($class->storage->schema_source)->search_rs($filter);
+        $iterator->result_class(ref $class || $class);
 
         return $iterator;
     };
@@ -272,13 +246,13 @@ sub reconcile {
                   (ref($cart) eq 'HASH' or UNIVERSAL::isa($cart, 'Handel::Cart') or $is_uuid);
 
         if (ref $cart eq 'HASH') {
-            $cart = $self->cart_class->load($cart)->first;
+            $cart = $self->storage->cart_class->load($cart)->first;
 
             throw Handel::Exception::Order( -details =>
                 translate(
                     'Could not find a cart matching the supplied search criteria') . '.') unless $cart;
         } elsif ($is_uuid) {
-            $cart = $self->cart_class->load({id => $cart})->first;
+            $cart = $self->storage->cart_class->load({id => $cart})->first;
 
             throw Handel::Exception::Order( -details =>
                 translate(
