@@ -1,4 +1,4 @@
-# $Id: Item.pm 1202 2006-06-04 18:59:10Z claco $
+# $Id: Item.pm 1314 2006-07-10 00:29:55Z claco $
 package Handel::Order::Item;
 use strict;
 use warnings;
@@ -9,21 +9,26 @@ BEGIN {
     use Handel::Currency;
     use Handel::L10N qw(translate);
 
-    use base qw/Handel::Storage/;
-    __PACKAGE__->schema_class('Handel::Order::Schema');
-    __PACKAGE__->schema_source('Items');
-    __PACKAGE__->setup_column_accessors;
-    __PACKAGE__->add_constraint('quantity', quantity => \&constraint_quantity);
-    __PACKAGE__->add_constraint('price',    price    => \&constraint_price);
-    __PACKAGE__->add_constraint('id',       id       => \&constraint_uuid);
-    __PACKAGE__->add_constraint('orderid',  orderid  => \&constraint_uuid);
-    __PACKAGE__->add_constraint('total',    total    => \&constraint_price);
-
-    __PACKAGE__->default_values({
-        id    => \&Handel::Storage::uuid,
-        price => 0,
-        total => 0
+    use base qw/Handel::Base/;
+    __PACKAGE__->storage({
+        schema_class     => 'Handel::Order::Schema',
+        schema_source    => 'Items',
+        currency_columns => [qw/price total/],
+        constraints      => {
+            quantity     => {'Check Quantity' => \&constraint_quantity},
+            price        => {'Check Price'    => \&constraint_price},
+            total        => {'Check Total'    => \&constraint_price},
+            id           => {'Check Id'       => \&constraint_uuid},
+            orderid      => {'Check Order Id' => \&constraint_uuid}
+        },
+        default_values   => {
+            id           => __PACKAGE__->storage_class->can('new_uuid'),
+            price        => 0,
+            quantity     => 1,
+            total        => 0
+        }
     });
+    __PACKAGE__->create_accessors;
 };
 
 sub new {
@@ -34,7 +39,8 @@ sub new {
             ref($data) eq 'HASH';
 
     my $self = bless {
-        storage => $class->schema_instance->resultset($class->schema_source)->create($data)
+        result => $class->storage->schema_instance->resultset($class->storage->schema_source)->create($data),
+        autoupdate => $class->storage->autoupdate
     }, $class;
 
     return $self;
