@@ -1,4 +1,4 @@
-# $Id: Cart.pm 1194 2006-06-02 03:00:10Z claco $
+# $Id: Cart.pm 1312 2006-07-09 19:46:15Z claco $
 package Template::Plugin::Handel::Cart;
 use strict;
 use warnings;
@@ -20,7 +20,7 @@ sub new {
 sub load {
     my ($class, $context) = @_;
 
-    return $class;
+    return ref $class || $class;
 };
 
 package Template::Plugin::Handel::Cart::Proxy;
@@ -28,6 +28,8 @@ use strict;
 use warnings;
 use base qw/Handel::Cart/;
 
+__PACKAGE__->init_storage;
+
 sub load {
     my ($self, $filter) = @_;
     my $iterator = $self->SUPER::load($filter);
@@ -42,6 +44,12 @@ sub items {
     return $iterator;
 };
 
+sub uuid {
+    return shift->storage->new_uuid;
+};
+
+*guid = \&uuid;
+
 1;
 __END__
 
