@@ -1,4 +1,4 @@
-# $Id: InitializeTotals.pm 693 2005-08-10 01:25:49Z claco $
+# $Id: InitializeTotals.pm 1168 2006-05-31 01:53:05Z claco $
 package Handel::TestPipeline::InitializeTotals;
 use strict;
 use warnings;
@@ -19,8 +19,8 @@ sub handler {
         my $subtotal = 0;
 
         eval {
-            my $items = $order->items(undef, RETURNAS_ITERATOR);
-            while (my $item = $items->next) {
+            my @items = $order->items;
+            foreach my $item (@items) {
                 $item->total($item->quantity*$item->price);
                 $subtotal += $item->total;
             };
@@ -40,4 +40,4 @@ sub handler {
     };
 };
 
-1;
\ No newline at end of file
+1;
