@@ -1,4 +1,4 @@
-# $Id: ValidateError.pm 693 2005-08-10 01:25:49Z claco $
+# $Id: ValidateError.pm 1168 2006-05-31 01:53:05Z claco $
 package Handel::TestPipeline::ValidateError;
 use strict;
 use warnings;
@@ -19,8 +19,8 @@ sub handler {
         my $subtotal = 0;
 
         eval {
-            my $items = $order->items(undef, RETURNAS_ITERATOR);
-            while (my $item = $items->next) {
+            my @items = $order->items;
+            foreach my $item (@items) {
                 $item->sku('ERRORSKU');
             };
             $order->billtofirstname('ErrorBillToFirstName');
@@ -42,4 +42,4 @@ sub handler {
     };
 };
 
-1;
\ No newline at end of file
+1;
